function StatLogger()
{
    this.getQueryString = function( params )
    {
        var query_string = '';
        var counter = 0;
        for( var key in params )
        {
            counter++;
            query_string += ( counter > 1 ) ? '&' : '';
            query_string += key + '=' + params[ key ];
        }

        return query_string;
    }

    this.getWidgetId = function()
    {
        var wuid = document.location.host;
        return wuid.replace( 'wuid-', '' );
    }

    this.getHardwareId = function()
    {
        var hid = this.getWidgetId();
        hid = hid.replace( /[^\d\w]/g, '' );
        hid = hid.substr( 0, 24 );

        return hid;
    }

    this.getBaseParams = function()
    {
        return {
            tid: widget.preferences.id,
            hid: this.hardwareId,
            sid: 0,
            ver: widget.preferences.version
        };
    }

    this.execPostRequest = function( url, params )
    {
        try
        {
            var query_string = this.getQueryString( params );

            var request = new XMLHttpRequest();
            request.open( 'POST', url );
            request.overrideMimeType( "text/plain; charset=x-user-defined" );
            request.setRequestHeader( "Content-type", "application/x-www-form-urlencoded" );
            request.setRequestHeader( "Content-length", query_string.length );

            request.onreadystatechange = function () {
                if( request.readyState == 4 )
                {
                    //console.log( 'Toolbar launch request done!' );
                    //console.log( 'Response: ' + request.responseText );
                }
            };
            request.send( query_string );
        }
        catch( e )
        {
            console.log( e.message );
        }
    }

    this.execGetRequest = function( url, params )
    {
        try
        {
            var query_string = this.getQueryString( params );

            var request = new XMLHttpRequest();
            request.open( 'GET', url + '?' + query_string );
            request.overrideMimeType( "text/plain; charset=x-user-defined" );

            request.onreadystatechange = function () {
                if( request.readyState == 4 )
                {
                    //console.log( 'Toolbar launch request done!' );
                    //console.log( 'Response: ' + request.responseText );
                }
            };
            request.send();
        }
        catch( e )
        {
            console.log( e.message );
        }
    }

    this.execGetRequestViaScript = function( url, params )
    {
        try
        {
            var query_string = this.getQueryString( params );

            var script = document.createElement( 'script' );
            script.type = 'text/plain';
            script.src = url + '?' + query_string;
            document.body.appendChild( script );
        }
        catch( e )
        {
            console.log( e.message );
        }
    }

    this.reportLaunch = function()
    {
        console.log( 'reportLaunch()' );

        var params = this.getBaseParams();
        params.mode = 'plugin_launch';

        this.execPostRequest(
            this.statsServerUrl + "report.php",
            params
        );
    }

    this.reportInstall = function()
    {
        console.log( 'reportInstall()' );

        var params = this.getBaseParams();
        params.mode = 'installed';

        this.execPostRequest(
            this.statsServerUrl + "install.php",
            params
        );
    }

    this.checkForInstall = function()
    {
        if( typeof widget.preferences[ 'installed' ] === 'undefined' )
        {
            console.log( 'First launch! Reporting about new install...' );
            this.reportInstall();
            widget.preferences[ 'installed' ] = true;
        }
        else
        {
            console.log( 'Installed! Doing nothing.' );
        }
    }

    this.reportComponentUsage = function( componentType, url )
    {
        var params = this.getBaseParams();
        params.mode = 'usage';
        params.keyword = componentType;

        if( url !== undefined )
        {
            params.url = url;
        }

        this.execPostRequest(
            this.statsServerUrl + "report.php",
            params
        );
    }

    this.statsServerHost = widget.preferences.statsServerHost;
    this.statsServerUrl = 'http://' + this.statsServerHost + '/';
    this.hardwareId = this.getHardwareId();
}